import { Component, Prop, h, State } from '@stencil/core';
export class AccountSummaryComponent {
  /**
   * When component loads
   * fetch account transactions
   *
   * @returns
   */
  componentWillLoad() {
    return this.fetchAccountSummary();
  }
  /**
   * Fetch account transactions
   */
  async fetchAccountSummary() {
    this.loading = true;
    let result = await this.getAccountSummary.summary({});
    if (result)
      this.summary = {
        total_amount: result.total_amount,
        total_pending: result.total_pending,
        total_converted: result.total_converted
      };
    this.loading = false;
  }
  render() {
    return h("div", { class: "grid grid-cols-1" },
      h("div", { class: "relative z-10 col-start-1 row-start-1 px-4 pt-10 pb-3 bg-gradient-to-t from-black" },
        h("p", { class: "text-sm font-medium text-white" }, "Current balance"),
        h("h2", { class: "text-6xl font-semibold text-white" },
          "\u20B9 ",
          this.summary.total_amount)),
      h("div", { class: "col-start-1 row-start-2 px-4" },
        h("div", { class: "flex items-center text-sm font-medium my-2 text-gray-400" },
          h("div", { class: "ml-1 mr-5" },
            h("span", { class: "text-lg" },
              "\u20B9",
              this.summary.total_pending)),
          h("div", null, "Pending amount")),
        h("hr", { class: "w-16 border-gray-300 hidden sm:block" })),
      h("div", { class: "col-start-1 row-start-1 flex" },
        h("div", { class: "w-full grid grid-cols-3 grid-rows-2 gap-2" },
          h("div", { class: "relative col-span-3 row-span-2 bg-gray-400" }))));
  }
  static get is() { return "account-summary-component"; }
  static get originalStyleUrls() { return {
    "$": ["account-summary-component.css"]
  }; }
  static get styleUrls() { return {
    "$": ["account-summary-component.css"]
  }; }
  static get properties() { return {
    "getAccountSummary": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "GetAccountSummary",
        "resolved": "GetAccountSummary",
        "references": {
          "GetAccountSummary": {
            "location": "import",
            "path": "../../../domain/usages/get-account-sumary"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Get account summary"
      }
    }
  }; }
  static get states() { return {
    "loading": {},
    "summary": {}
  }; }
}
