import { r as registerInstance, h } from './index-36056e77.js';

const accountSummaryComponentCss = "";

const AccountSummaryComponent = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
  }
  /**
   * When component loads
   * fetch account transactions
   *
   * @returns
   */
  componentWillLoad() {
    return this.fetchAccountSummary();
  }
  /**
   * Fetch account transactions
   */
  async fetchAccountSummary() {
    this.loading = true;
    let result = await this.getAccountSummary.summary({});
    if (result)
      this.summary = {
        total_amount: result.total_amount,
        total_pending: result.total_pending,
        total_converted: result.total_converted
      };
    this.loading = false;
  }
  render() {
    return h("div", { class: "grid grid-cols-1" }, h("div", { class: "relative z-10 col-start-1 row-start-1 px-4 pt-10 pb-3 bg-gradient-to-t from-black" }, h("p", { class: "text-sm font-medium text-white" }, "Current balance"), h("h2", { class: "text-6xl font-semibold text-white" }, "\u20B9 ", this.summary.total_amount)), h("div", { class: "col-start-1 row-start-2 px-4" }, h("div", { class: "flex items-center text-sm font-medium my-2 text-gray-400" }, h("div", { class: "ml-1 mr-5" }, h("span", { class: "text-lg" }, "\u20B9", this.summary.total_pending)), h("div", null, "Pending amount")), h("hr", { class: "w-16 border-gray-300 hidden sm:block" })), h("div", { class: "col-start-1 row-start-1 flex" }, h("div", { class: "w-full grid grid-cols-3 grid-rows-2 gap-2" }, h("div", { class: "relative col-span-3 row-span-2 bg-gray-400" }))));
  }
};
AccountSummaryComponent.style = accountSummaryComponentCss;

var _a;
const BASE_URL = "http://localhost:8002/api/v2";
const AUTH_HEADER = "GA-Authorization";
const AUTH_TOKEN = (_a = "AUTH_TOKEN") !== null && _a !== void 0 ? _a : "auth_token";

class RemoteGetAccountSummary {
  constructor(url, httpGetClient) {
    this.url = url;
    this.httpGetClient = httpGetClient;
  }
  async summary(params) {
    const httpResponse = await this.httpGetClient.get({
      url: this.url,
      query: params,
      headers: {
        "Content-Type": "application/json",
        "Accept": "application/json"
      },
    });
    return httpResponse;
  }
}

function decrypt(value) {
  return atob(value);
}

class FetchHttpClient {
  /**
   * Singleton class private contructor
   */
  constructor() { }
  /**
   * Singleton class create instance
   */
  static getInstance() {
    if (!FetchHttpClient.instance) {
      FetchHttpClient.instance = new FetchHttpClient();
      FetchHttpClient.token = FetchHttpClient.instance.getAuthToken();
    }
    return FetchHttpClient.instance;
  }
  /**
   * Get auth token
   *
   * @returns string | null
   */
  getAuthToken() {
    if (AUTH_TOKEN) {
      let ltoken = localStorage.getItem(AUTH_TOKEN);
      if (ltoken && ltoken != "") {
        return decrypt(JSON.parse(ltoken));
      }
      return "";
    }
    return "";
  }
  ;
  /**
   * Post request
   * @param params
   * @returns
   */
  async post(params) {
    let response;
    try {
      response = await fetch(params.url, {
        method: 'POST',
        body: JSON.stringify(params.body),
        headers: this.prepareAuthHeader(params.headers)
      });
    }
    catch (error) {
      response = error.json();
    }
    return response.json();
  }
  async put(params) {
    let response;
    try {
      response = await fetch(params.url, {
        method: 'PUT',
        body: JSON.stringify(params.body),
        headers: this.prepareAuthHeader(params.headers)
      });
    }
    catch (error) {
      response = error.json();
    }
    return response.json();
  }
  async get(params) {
    let response;
    try {
      response = await fetch(params.url + new URLSearchParams(params.query), {
        headers: this.prepareAuthHeader(params.headers)
      });
    }
    catch (error) {
      response = error.json();
    }
    return response.json();
  }
  /**
   * Prepare auth headers
   *
   * @param headers
   * @returns
   */
  prepareAuthHeader(headers) {
    if (!FetchHttpClient.token)
      FetchHttpClient.token = FetchHttpClient.instance.getAuthToken();
    if (headers && FetchHttpClient.token && FetchHttpClient.token != "")
      headers[AUTH_HEADER] = FetchHttpClient.token;
    return headers;
  }
}

const AccountSummaryFactory = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
  }
  render() {
    let httpClient = FetchHttpClient.getInstance();
    const getAccountSummary = new RemoteGetAccountSummary(`${BASE_URL}/accounts/totals`, httpClient);
    return h("account-summary-component", { getAccountSummary: getAccountSummary });
  }
};

class AppDate extends Date {
  constructor() {
    super(...arguments);
    this.shortMonthNames = [
      "Jan", "Feb", "Mar", "Apr", "May", "Jun",
      "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"
    ];
  }
  toStandardDate() {
    var mm = this.getMonth() + 1;
    var dd = this.getDate();
    return [this.getFullYear(), '-',
      (mm > 9 ? '' : '0') + mm, '-',
      (dd > 9 ? '' : '0') + dd
    ].join('');
  }
  toDateMonthStr() {
    var dd = this.getDate();
    return [
      (dd > 9 ? '' : '0') + dd, ", ",
      this.shortMonthNames[this.getMonth()]
    ].join('');
  }
}

const accountTransactionComponentCss = "";

const AccountTransactionComponent = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
  }
  render() {
    let credit = this.transaction.type == 'credit' ? true : false;
    return h("li", { class: "p-2 pr-0 flex border-t pb-5 rounded-5 border-blue-100" }, h("div", { class: `text-lg flex-initial rounded-full h-20 w-20 flex text-white items-center justify-center font-medium ` + (credit ? "bg-green-300" : 'bg-red-300') }, "\u20B9", this.transaction.amount), h("div", { class: "flex-1" }, h("div", { class: "text-xs float-right rounded-l-full py-1 px-4 bg-gray-300" }, (new AppDate()).toDateMonthStr()), h("div", { class: "pl-5" }, h("div", { class: "text-lg pr-16" }, this.transaction.title), h("div", { class: "text-sm text-gray-400" }, this.transaction.description))));
  }
};
AccountTransactionComponent.style = accountTransactionComponentCss;

const accountTransactionListComponentCss = "";

const AccountTransactionListComponent = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
  }
  /**
   * When component loads
   * fetch account transactions
   *
   * @returns
   */
  componentWillLoad() {
    return this.fetchAccountTransactions();
  }
  /**
   * Fetch account transactions
   */
  async fetchAccountTransactions() {
    this.loading = true;
    let result = await this.getAccountTransactionList.get({});
    if (result)
      this.transactions = result.account_transactions;
    this.loading = false;
  }
  render() {
    return h("div", { class: "overflow-y-auto h-96" }, h("ul", { class: "list-none" }, this.transactions.map(t => {
      return h("account-transaction-component", { transaction: t });
    })));
  }
};
AccountTransactionListComponent.style = accountTransactionListComponentCss;

class RemoteGetTransactionList {
  constructor(url, httpGetClient) {
    this.url = url;
    this.httpGetClient = httpGetClient;
  }
  async get(params) {
    const httpResponse = await this.httpGetClient.get({
      url: this.url,
      query: params,
      headers: {
        "Content-Type": "application/json",
        "Accept": "application/json"
      },
    });
    return httpResponse;
  }
}

const AccountTransactionListComponentFactory = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
  }
  render() {
    let httpClient = FetchHttpClient.getInstance();
    const remoteGetCategoryList = new RemoteGetTransactionList(`${BASE_URL}/account_transactions`, httpClient);
    return h("account-transaction-list-component", { getAccountTransactionList: remoteGetCategoryList });
  }
};

const walletComponentCss = "/*! tailwindcss v2.1.2 | MIT License | https://tailwindcss.com*//*! modern-normalize v1.1.0 | MIT License | https://github.com/sindresorhus/modern-normalize */:host{line-height:1.15;-moz-tab-size:4;-o-tab-size:4;tab-size:4;-webkit-text-size-adjust:100%}body{font-family:system-ui,-apple-system,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji;margin:0}hr{color:inherit;height:0}summary{display:list-item}h1,h2,hr,p,ul{margin:0}ul{list-style:none;padding:0}:host{font-family:ui-sans-serif,system-ui,-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica Neue,Arial,Noto Sans,sans-serif,Apple Color Emoji,Segoe UI Emoji,Segoe UI Symbol,Noto Color Emoji;line-height:1.5}body{font-family:inherit;line-height:inherit}*,:after,:before{border:0 solid #e5e7eb;box-sizing:border-box}hr{border-top-width:1px}h1,h2{font-size:inherit;font-weight:inherit}.bg-gray-300{--tw-bg-opacity:1;background-color:rgba(209,213,219,var(--tw-bg-opacity))}.bg-gray-400{--tw-bg-opacity:1;background-color:rgba(156,163,175,var(--tw-bg-opacity))}.bg-red-300{--tw-bg-opacity:1;background-color:rgba(252,165,165,var(--tw-bg-opacity))}.bg-green-300{--tw-bg-opacity:1;background-color:rgba(110,231,183,var(--tw-bg-opacity))}.bg-gradient-to-t{background-image:linear-gradient(to top,var(--tw-gradient-stops))}.from-black{--tw-gradient-from:#000;--tw-gradient-stops:var(--tw-gradient-from),var(--tw-gradient-to,transparent)}.border-gray-300{--tw-border-opacity:1;border-color:rgba(209,213,219,var(--tw-border-opacity))}.border-blue-100{--tw-border-opacity:1;border-color:rgba(219,234,254,var(--tw-border-opacity))}.rounded-full{border-radius:9999px}.rounded-l-full{border-bottom-left-radius:9999px;border-top-left-radius:9999px}.border-t{border-top-width:1px}.flex{display:flex}.grid{display:grid}.hidden{display:none}.items-center{align-items:center}.justify-center{justify-content:center}.flex-1{flex:1 1 0%}.flex-initial{flex:0 1 auto}.float-right{float:right}.font-medium{font-weight:500}.font-semibold{font-weight:600}.h-20{height:5rem}.h-96{height:24rem}.text-xs{font-size:.75rem;line-height:1rem}.text-sm{font-size:.875rem;line-height:1.25rem}.text-lg{font-size:1.125rem;line-height:1.75rem}.text-6xl{font-size:3.75rem;line-height:1}.list-none{list-style-type:none}.my-2{margin-bottom:.5rem;margin-top:.5rem}.ml-1{margin-left:.25rem}.mr-5{margin-right:1.25rem}.overflow-y-auto{overflow-y:auto}.p-2{padding:.5rem}.py-1{padding-bottom:.25rem;padding-top:.25rem}.px-4{padding-left:1rem;padding-right:1rem}.pr-0{padding-right:0}.pb-3{padding-bottom:.75rem}.pb-5{padding-bottom:1.25rem}.pl-5{padding-left:1.25rem}.pt-10{padding-top:2.5rem}.pr-16{padding-right:4rem}.relative{position:relative}*{--tw-shadow:0 0 transparent;--tw-ring-inset:var(--tw-empty, );--tw-ring-offset-width:0px;--tw-ring-offset-color:#fff;--tw-ring-color:rgba(59,130,246,0.5);--tw-ring-offset-shadow:0 0 transparent;--tw-ring-shadow:0 0 transparent}.text-center{text-align:center}.text-white{--tw-text-opacity:1;color:rgba(255,255,255,var(--tw-text-opacity))}.text-gray-400{--tw-text-opacity:1;color:rgba(156,163,175,var(--tw-text-opacity))}.text-blue-600{--tw-text-opacity:1;color:rgba(37,99,235,var(--tw-text-opacity))}.uppercase{text-transform:uppercase}.w-16{width:4rem}.w-20{width:5rem}.w-full{width:100%}.z-10{z-index:10}.gap-2{gap:.5rem}.grid-cols-1{grid-template-columns:repeat(1,minmax(0,1fr))}.grid-cols-3{grid-template-columns:repeat(3,minmax(0,1fr))}.col-span-3{grid-column:span 3/span 3}.col-start-1{grid-column-start:1}.grid-rows-2{grid-template-rows:repeat(2,minmax(0,1fr))}.row-span-2{grid-row:span 2/span 2}.row-start-1{grid-row-start:1}.row-start-2{grid-row-start:2}@-webkit-keyframes spin{to{transform:rotate(1turn)}}@keyframes spin{to{transform:rotate(1turn)}}@-webkit-keyframes ping{75%,to{opacity:0;transform:scale(2)}}@keyframes ping{75%,to{opacity:0;transform:scale(2)}}@-webkit-keyframes pulse{50%{opacity:.5}}@keyframes pulse{50%{opacity:.5}}@-webkit-keyframes bounce{0%,to{-webkit-animation-timing-function:cubic-bezier(.8,0,1,1);animation-timing-function:cubic-bezier(.8,0,1,1);transform:translateY(-25%)}50%{-webkit-animation-timing-function:cubic-bezier(0,0,.2,1);animation-timing-function:cubic-bezier(0,0,.2,1);transform:none}}@keyframes bounce{0%,to{-webkit-animation-timing-function:cubic-bezier(.8,0,1,1);animation-timing-function:cubic-bezier(.8,0,1,1);transform:translateY(-25%)}50%{-webkit-animation-timing-function:cubic-bezier(0,0,.2,1);animation-timing-function:cubic-bezier(0,0,.2,1);transform:none}}:host{display:block}@media (min-width:640px){.sm\\:block{display:block}}";

const WalletComponent = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
  }
  render() {
    return h("div", { class: "grid grid-cols-1" }, h("div", { class: "col-start-1" }, h("account-summary-component-factory", null), h("h1", { class: "uppercase text-blue-600 text-center border-t p-2" }, "Account transactions"), h("account-transaction-list-component-factory", null)));
  }
};
WalletComponent.style = walletComponentCss;

export { AccountSummaryComponent as account_summary_component, AccountSummaryFactory as account_summary_component_factory, AccountTransactionComponent as account_transaction_component, AccountTransactionListComponent as account_transaction_list_component, AccountTransactionListComponentFactory as account_transaction_list_component_factory, WalletComponent as wallet_component };
